@@ -259,6 +259,12 @@ class Student(Base):
     status = Column('status', Integer)
     reg_date = Column('student_reg_date', DateTime)
 
+    # Пол
+    sex = Column('students_sex', Integer)
+
+    # Дата рождения
+    birth_date = Column('students_birth_date', DateTime)
+
     # ФИО студента
     last_name = Column('students_sname', String(100))
     first_name = Column('students_name', String(100))
@@ -270,6 +276,11 @@ class Student(Base):
 
     email = Column('students_email', String(25))
 
+    # Документ
+    document_identity_number = Column('students_document_identity_number', String(50))
+    document_identity_date = Column('students_document_identity_date', DateTime)
+    document_identity_issued = Column('students_document_identity_issued', String(100))
+
     # ИИН студента
     identify_code = Column('students_identify_code', String(50))
 
